@@ -1,7 +1,7 @@
 package App::ProgUtils;
 
-our $DATE = '2015-03-21'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,12 +58,26 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.15 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2015-03-21.
+This document describes version 0.16 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
 This distribution provides the following command-line utilities related to
-programs found in PATH.
+programs found in PATH:
+
+=over
+
+=item * L<progcat>
+
+=item * L<progedit>
+
+=item * L<progless>
+
+=item * L<progman>
+
+=item * L<progpath>
+
+=back
 
 The main feature of these utilities is tab completion.
 
@@ -93,16 +107,12 @@ L<App::IODUtils>, utilities related to L<IOD> configuration files.
 
 L<App::LedgerUtils>, utilities related to Ledger CLI files.
 
-L<App::OrgUtils>, utilities related to Org files.
-
 L<App::PlUtils>, utilities related to Perl scripts.
 
 L<App::PMUtils>, utilities related to Perl modules.
 
 L<App::ProgUtils>, utilities related to programs.
 
-L<App::UpfUtils>, utilities related to Unix password/shadow files.
-
 L<App::WeaverUtils>, utilities related to L<Pod::Weaver>.
 
 =head1 HOMEPAGE
